# eric7.Plugins.VcsPlugins.vcsSubversion.SvnLogBrowserDialog

Module implementing a dialog to browse the log history.

### Global Attributes

None

### Classes

SvnLogBrowserDialog | Class implementing a dialog to browse the log history.

### Functions

None

## SvnLogBrowserDialog

Class implementing a dialog to browse the log history.

### Derived from

QWidget, Ui_SvnLogBrowserDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnLogBrowserDialog | Constructor
__addFinishCallback | Private method to add a method to be called once the process finished.
__diffRevisions | Private method to do a diff of two revisions.
__filterLogs | Private method to filter the log entries.
__finish | Private slot called when the process finished or the user pressed the button.
__generateFileItem | Private method to generate a changed files tree entry.
__generateLogItem | Private method to generate a log tree entry.
__getLogEntries | Private method to retrieve log entries from the repository.
__initData | Private method to (re-)initialize some data.
__procFinished | Private slot connected to the finished signal.
__processBuffer | Private method to process the buffered output of the svn log command.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
__resetUI | Private method to reset the user interface.
__resizeColumnsFiles | Private method to resize the changed files tree columns.
__resizeColumnsLog | Private method to resize the log tree columns.
__resortFiles | Private method to resort the changed files tree.
__resortLog | Private method to resort the log tree.
closeEvent | Protected slot implementing a close event handler.
keyPressEvent | Protected slot to handle a key press event.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_diffPreviousButton_clicked | Private slot to handle the Diff to Previous button.
on_diffRevisionsButton_clicked | Private slot to handle the Compare Revisions button.
on_downButton_clicked | Private slot to move the current item down one entry.
on_fieldCombo_activated | Private slot called, when a new filter field is selected.
on_fromDate_dateChanged | Private slot called, when the from date changes.
on_input_returnPressed | Private slot to handle the press of the return key in the input field.
on_logTree_currentItemChanged | Private slot called, when the current item of the log tree changes.
on_logTree_itemSelectionChanged | Private slot called, when the selection has changed.
on_nextButton_clicked | Private slot to handle the Next button.
on_passwordCheckBox_toggled | Private slot to handle the password checkbox toggled.
on_rxEdit_textChanged | Private slot called, when a filter expression is entered.
on_sendButton_clicked | Private slot to send the input to the subversion process.
on_stopCheckBox_clicked | Private slot called, when the stop on copy/move checkbox is clicked.
on_toDate_dateChanged | Private slot called, when the from date changes.
on_upButton_clicked | Private slot to move the current item up one entry.
show | Public slot to show the dialog.
start | Public slot to start the svn log command.

### Static Methods

None

#### SvnLogBrowserDialog (Constructor)

SvnLogBrowserDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### SvnLogBrowserDialog.__addFinishCallback

__addFinishCallback(callback)

Private method to add a method to be called once the process finished.

The callback methods are invoke in a FIFO style and are consumed. If a callback method needs to be called again, it must be added again.

callback (function)
  callback method

#### SvnLogBrowserDialog.__diffRevisions

__diffRevisions(rev1, rev2)

Private method to do a diff of two revisions.

rev1
  first revision number (integer)
rev2
  second revision number (integer)

#### SvnLogBrowserDialog.__filterLogs

__filterLogs()

Private method to filter the log entries.

#### SvnLogBrowserDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### SvnLogBrowserDialog.__generateFileItem

__generateFileItem(action, path, copyFrom, copyRev)

Private method to generate a changed files tree entry.

action
  indicator for the change action ("A", "D" or "M")
path
  path of the file in the repository (string)
copyFrom
  path the file was copied from (None, string)
copyRev
  revision the file was copied from (None, string)

Return:
  reference to the generated item (QTreeWidgetItem)

#### SvnLogBrowserDialog.__generateLogItem

__generateLogItem(author, date, message, revision, changedPaths)

Private method to generate a log tree entry.

author
  author info (string)
date
  date info (string)
message
  text of the log message (list of strings)
revision
  revision info (string)
changedPaths
  list of dictionary objects containing info about the changed files/directories

Return:
  reference to the generated item (QTreeWidgetItem)

#### SvnLogBrowserDialog.__getLogEntries

__getLogEntries(startRev=None)

Private method to retrieve log entries from the repository.

startRev
  revision number to start from (integer, string)

#### SvnLogBrowserDialog.__initData

__initData()

Private method to (re-)initialize some data.

#### SvnLogBrowserDialog.__procFinished

__procFinished(exitCode, exitStatus)

Private slot connected to the finished signal.

exitCode
  exit code of the process (integer)
exitStatus
  exit status of the process (QProcess.ExitStatus)

#### SvnLogBrowserDialog.__processBuffer

__processBuffer()

Private method to process the buffered output of the svn log command.

#### SvnLogBrowserDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the error pane.

#### SvnLogBrowserDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process and inserts it into a buffer.

#### SvnLogBrowserDialog.__resetUI

__resetUI()

Private method to reset the user interface.

#### SvnLogBrowserDialog.__resizeColumnsFiles

__resizeColumnsFiles()

Private method to resize the changed files tree columns.

#### SvnLogBrowserDialog.__resizeColumnsLog

__resizeColumnsLog()

Private method to resize the log tree columns.

#### SvnLogBrowserDialog.__resortFiles

__resortFiles()

Private method to resort the changed files tree.

#### SvnLogBrowserDialog.__resortLog

__resortLog()

Private method to resort the log tree.

#### SvnLogBrowserDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### SvnLogBrowserDialog.keyPressEvent

keyPressEvent(evt)

Protected slot to handle a key press event.

evt
  the key press event (QKeyEvent)

#### SvnLogBrowserDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### SvnLogBrowserDialog.on_diffPreviousButton_clicked

on_diffPreviousButton_clicked()

Private slot to handle the Diff to Previous button.

#### SvnLogBrowserDialog.on_diffRevisionsButton_clicked

on_diffRevisionsButton_clicked()

Private slot to handle the Compare Revisions button.

#### SvnLogBrowserDialog.on_downButton_clicked

on_downButton_clicked()

Private slot to move the current item down one entry.

#### SvnLogBrowserDialog.on_fieldCombo_activated

on_fieldCombo_activated(index)

Private slot called, when a new filter field is selected.

index (int)
  index of the selected entry

#### SvnLogBrowserDialog.on_fromDate_dateChanged

on_fromDate_dateChanged(date)

Private slot called, when the from date changes.

date
  new date (QDate)

#### SvnLogBrowserDialog.on_input_returnPressed

on_input_returnPressed()

Private slot to handle the press of the return key in the input field.

#### SvnLogBrowserDialog.on_logTree_currentItemChanged

on_logTree_currentItemChanged(current, previous)

Private slot called, when the current item of the log tree changes.

current
  reference to the new current item (QTreeWidgetItem)
previous
  reference to the old current item (QTreeWidgetItem)

#### SvnLogBrowserDialog.on_logTree_itemSelectionChanged

on_logTree_itemSelectionChanged()

Private slot called, when the selection has changed.

#### SvnLogBrowserDialog.on_nextButton_clicked

on_nextButton_clicked()

Private slot to handle the Next button.

#### SvnLogBrowserDialog.on_passwordCheckBox_toggled

on_passwordCheckBox_toggled(isOn)

Private slot to handle the password checkbox toggled.

isOn
  flag indicating the status of the check box (boolean)

#### SvnLogBrowserDialog.on_rxEdit_textChanged

on_rxEdit_textChanged(txt)

Private slot called, when a filter expression is entered.

txt
  filter expression (string)

#### SvnLogBrowserDialog.on_sendButton_clicked

on_sendButton_clicked()

Private slot to send the input to the subversion process.

#### SvnLogBrowserDialog.on_stopCheckBox_clicked

on_stopCheckBox_clicked(checked)

Private slot called, when the stop on copy/move checkbox is clicked.

checked
  flag indicating the checked state (boolean)

#### SvnLogBrowserDialog.on_toDate_dateChanged

on_toDate_dateChanged(date)

Private slot called, when the from date changes.

date
  new date (QDate)

#### SvnLogBrowserDialog.on_upButton_clicked

on_upButton_clicked()

Private slot to move the current item up one entry.

#### SvnLogBrowserDialog.show

show()

Public slot to show the dialog.

#### SvnLogBrowserDialog.start

start(fn, isFile=False)

Public slot to start the svn log command.

fn
  filename to show the log for (string)
isFile
  flag indicating log for a file is to be shown (boolean)

Up